@@ -123,6 +123,7 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Backup::Framework",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
@@ -252,6 +253,7 @@ types: list[str] = [
     "AWS::Config::OrganizationConformancePack",
     "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
+    "AWS::Connect::AgentStatus",
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
@@ -272,6 +274,7 @@ types: list[str] = [
     "AWS::Connect::TaskTemplate",
     "AWS::Connect::User",
     "AWS::Connect::UserHierarchyGroup",
+    "AWS::Connect::UserHierarchyStructure",
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ControlTower::EnabledBaseline",
@@ -287,6 +290,7 @@ types: list[str] = [
     "AWS::DAX::SubnetGroup",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
@@ -320,6 +324,7 @@ types: list[str] = [
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
@@ -566,6 +571,7 @@ types: list[str] = [
     "AWS::Glue::Table",
     "AWS::Glue::TableOptimizer",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::Grafana::Workspace",
     "AWS::Greengrass::ConnectorDefinition",
@@ -709,6 +715,7 @@ types: list[str] = [
     "AWS::Kendra::Faq",
     "AWS::Kendra::Index",
     "AWS::KendraRanking::ExecutionPlan",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalytics::Application",
@@ -807,10 +814,19 @@ types: list[str] = [
     "AWS::MediaConvert::Preset",
     "AWS::MediaConvert::Queue",
     "AWS::MediaLive::Channel",
+    "AWS::MediaLive::ChannelPlacementGroup",
+    "AWS::MediaLive::CloudWatchAlarmTemplate",
+    "AWS::MediaLive::CloudWatchAlarmTemplateGroup",
+    "AWS::MediaLive::Cluster",
+    "AWS::MediaLive::EventBridgeRuleTemplate",
+    "AWS::MediaLive::EventBridgeRuleTemplateGroup",
     "AWS::MediaLive::Input",
     "AWS::MediaLive::InputSecurityGroup",
     "AWS::MediaLive::Multiplex",
     "AWS::MediaLive::Multiplexprogram",
+    "AWS::MediaLive::Network",
+    "AWS::MediaLive::SdiSource",
+    "AWS::MediaLive::SignalMap",
     "AWS::MediaPackage::Asset",
     "AWS::MediaPackage::Channel",
     "AWS::MediaPackage::OriginEndpoint",
@@ -873,6 +889,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -892,6 +909,10 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PaymentCryptography::Alias",
+    "AWS::PaymentCryptography::Key",
     "AWS::Personalize::Dataset",
     "AWS::Personalize::DatasetGroup",
     "AWS::Personalize::Schema",
@@ -925,6 +946,7 @@ types: list[str] = [
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -955,6 +977,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -1059,6 +1082,7 @@ types: list[str] = [
     "AWS::SSMContacts::Rotation",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
+    "AWS::SSMQuickSetup::ConfigurationManager",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1067,6 +1091,7 @@ types: list[str] = [
     "AWS::SSO::PermissionSet",
     "AWS::SageMaker::App",
     "AWS::SageMaker::AppImageConfig",
+    "AWS::SageMaker::Cluster",
     "AWS::SageMaker::CodeRepository",
     "AWS::SageMaker::DataQualityJobDefinition",
     "AWS::SageMaker::Device",
@@ -1208,6 +1233,8 @@ types: list[str] = [
     "AWS::WAFv2::RuleGroup",
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
+    "AWS::Wisdom::AIPrompt",
+    "AWS::Wisdom::AIPromptVersion",
     "AWS::Wisdom::Assistant",
     "AWS::Wisdom::AssistantAssociation",
     "AWS::Wisdom::KnowledgeBase",
@@ -1308,6 +1335,7 @@ cached: list[str] = [
     "aws-apprunner-observabilityconfiguration.json",
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
+    "aws-apprunner-vpcingressconnection.json",
     "aws-appstream-appblock.json",
     "aws-appstream-appblockbuilder.json",
     "aws-appstream-application.json",
@@ -1327,7 +1355,6 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1342,7 +1369,6 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1353,6 +1379,7 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
@@ -1436,6 +1463,7 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
+    "aws-codebuild-fleet.json",
     "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
@@ -1480,6 +1508,7 @@ cached: list[str] = [
     "aws-config-organizationconformancepack.json",
     "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
+    "aws-connect-agentstatus.json",
     "aws-connect-approvedorigin.json",
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
@@ -1500,6 +1529,7 @@ cached: list[str] = [
     "aws-connect-tasktemplate.json",
     "aws-connect-user.json",
     "aws-connect-userhierarchygroup.json",
+    "aws-connect-userhierarchystructure.json",
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-controltower-enabledbaseline.json",
@@ -1534,6 +1564,7 @@ cached: list[str] = [
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
@@ -1563,6 +1594,7 @@ cached: list[str] = [
     "aws-directoryservice-simplead.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
@@ -1792,6 +1824,7 @@ cached: list[str] = [
     "aws-glue-table.json",
     "aws-glue-tableoptimizer.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-grafana-workspace.json",
     "aws-greengrass-connectordefinition.json",
@@ -1823,7 +1856,6 @@ cached: list[str] = [
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
-    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-policy.json",
     "aws-iam-role.json",
@@ -1932,6 +1964,7 @@ cached: list[str] = [
     "aws-kendra-faq.json",
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
@@ -1982,6 +2015,7 @@ cached: list[str] = [
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
     "aws-location-apikey.json",
+    "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
     "aws-location-routecalculator.json",
@@ -2023,10 +2057,19 @@ cached: list[str] = [
     "aws-mediaconvert-preset.json",
     "aws-mediaconvert-queue.json",
     "aws-medialive-channel.json",
+    "aws-medialive-channelplacementgroup.json",
+    "aws-medialive-cloudwatchalarmtemplate.json",
+    "aws-medialive-cloudwatchalarmtemplategroup.json",
+    "aws-medialive-cluster.json",
+    "aws-medialive-eventbridgeruletemplate.json",
+    "aws-medialive-eventbridgeruletemplategroup.json",
     "aws-medialive-input.json",
     "aws-medialive-inputsecuritygroup.json",
     "aws-medialive-multiplex.json",
     "aws-medialive-multiplexprogram.json",
+    "aws-medialive-network.json",
+    "aws-medialive-sdisource.json",
+    "aws-medialive-signalmap.json",
     "aws-mediapackage-asset.json",
     "aws-mediapackage-channel.json",
     "aws-mediapackage-originendpoint.json",
@@ -2045,6 +2088,7 @@ cached: list[str] = [
     "aws-mediatailor-sourcelocation.json",
     "aws-mediatailor-vodsource.json",
     "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
     "aws-memorydb-user.json",
@@ -2052,6 +2096,7 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -2088,9 +2133,9 @@ cached: list[str] = [
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
     "aws-opensearchserverless-lifecyclepolicy.json",
-    "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -2106,11 +2151,15 @@ cached: list[str] = [
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-osis-pipeline.json",
+    "aws-paymentcryptography-alias.json",
+    "aws-paymentcryptography-key.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-personalize-dataset.json",
     "aws-personalize-datasetgroup.json",
     "aws-personalize-schema.json",
@@ -2140,6 +2189,7 @@ cached: list[str] = [
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
@@ -2169,6 +2219,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -2236,12 +2287,12 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-device.json",
     "aws-sagemaker-devicefleet.json",
     "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -2325,6 +2376,7 @@ cached: list[str] = [
     "aws-ses-mailmanagerruleset.json",
     "aws-ses-mailmanagertrafficpolicy.json",
     "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
@@ -2356,6 +2408,7 @@ cached: list[str] = [
     "aws-ssmcontacts-rotation.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
+    "aws-ssmquicksetup-configurationmanager.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -2373,7 +2426,6 @@ cached: list[str] = [
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
     "aws-timestream-database.json",
-    "aws-timestream-influxdbinstance.json",
     "aws-timestream-scheduledquery.json",
     "aws-timestream-table.json",
     "aws-transfer-agreement.json",
@@ -2422,6 +2474,7 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
+    "aws-wisdom-aiprompt.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
     "aws-wisdom-knowledgebase.json",
