@@ -93,6 +93,7 @@ types: list[str] = [
     "AWS::Backup::BackupPlan",
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
     "AWS::BackupGateway::Hypervisor",
@@ -187,6 +188,7 @@ types: list[str] = [
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
@@ -392,6 +394,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -438,6 +441,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -491,8 +495,17 @@ types: list[str] = [
     "AWS::MediaConnect::FlowSource",
     "AWS::MediaConnect::FlowVpcInterface",
     "AWS::MediaConnect::Gateway",
+    "AWS::MediaLive::ChannelPlacementGroup",
+    "AWS::MediaLive::CloudWatchAlarmTemplate",
+    "AWS::MediaLive::CloudWatchAlarmTemplateGroup",
+    "AWS::MediaLive::Cluster",
+    "AWS::MediaLive::EventBridgeRuleTemplate",
+    "AWS::MediaLive::EventBridgeRuleTemplateGroup",
     "AWS::MediaLive::Multiplex",
     "AWS::MediaLive::Multiplexprogram",
+    "AWS::MediaLive::Network",
+    "AWS::MediaLive::SdiSource",
+    "AWS::MediaLive::SignalMap",
     "AWS::MediaPackage::Asset",
     "AWS::MediaPackage::Channel",
     "AWS::MediaPackage::OriginEndpoint",
@@ -554,6 +567,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
@@ -581,6 +596,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RefactorSpaces::Application",
     "AWS::RefactorSpaces::Environment",
@@ -634,6 +650,9 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::ReceiptFilter",
+    "AWS::SES::ReceiptRule",
+    "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
     "AWS::SNS::Subscription",
@@ -753,6 +772,16 @@ types: list[str] = [
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
     "AWS::VerifiedPermissions::PolicyTemplate",
+    "AWS::VpcLattice::AccessLogSubscription",
+    "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourcePolicy",
+    "AWS::VpcLattice::Rule",
+    "AWS::VpcLattice::Service",
+    "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
+    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
+    "AWS::VpcLattice::TargetGroup",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -800,6 +829,22 @@ cached: list[str] = [
     "aws-amplifyuibuilder-component.json",
     "aws-amplifyuibuilder-form.json",
     "aws-amplifyuibuilder-theme.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
@@ -816,7 +861,6 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -838,7 +882,6 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -848,7 +891,6 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -857,6 +899,7 @@ cached: list[str] = [
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
     "aws-backupgateway-hypervisor.json",
@@ -961,6 +1004,7 @@ cached: list[str] = [
     "aws-directoryservice-microsoftad.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
@@ -989,6 +1033,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1004,10 +1049,7 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
-    "aws-ec2-networkinsightsaccessscope.json",
     "aws-ec2-networkinsightsaccessscopeanalysis.json",
-    "aws-ec2-networkinsightspath.json",
-    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-networkperformancemetricsubscription.json",
@@ -1036,12 +1078,14 @@ cached: list[str] = [
     "aws-ec2-transitgatewaymulticastgroupsource.json",
     "aws-ec2-transitgatewaypeeringattachment.json",
     "aws-ec2-transitgatewayroute.json",
+    "aws-ec2-transitgatewayroutetable.json",
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1133,6 +1177,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1142,6 +1187,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -1181,12 +1227,14 @@ cached: list[str] = [
     "aws-internetmonitor-monitor.json",
     "aws-iot-policyprincipalattachment.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1197,7 +1245,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1230,6 +1277,17 @@ cached: list[str] = [
     "aws-mediaconnect-flowsource.json",
     "aws-mediaconnect-flowvpcinterface.json",
     "aws-mediaconnect-gateway.json",
+    "aws-medialive-channelplacementgroup.json",
+    "aws-medialive-cloudwatchalarmtemplate.json",
+    "aws-medialive-cloudwatchalarmtemplategroup.json",
+    "aws-medialive-cluster.json",
+    "aws-medialive-eventbridgeruletemplate.json",
+    "aws-medialive-eventbridgeruletemplategroup.json",
+    "aws-medialive-multiplex.json",
+    "aws-medialive-multiplexprogram.json",
+    "aws-medialive-network.json",
+    "aws-medialive-sdisource.json",
+    "aws-medialive-signalmap.json",
     "aws-mediapackage-asset.json",
     "aws-mediapackage-channel.json",
     "aws-mediapackage-originendpoint.json",
@@ -1238,7 +1296,6 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
-    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediatailor-channel.json",
     "aws-mediatailor-channelpolicy.json",
@@ -1289,11 +1346,10 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-pcaconnectorad-connector.json",
-    "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
-    "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
@@ -1320,6 +1376,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -1373,7 +1430,6 @@ cached: list[str] = [
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1400,7 +1456,6 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -1439,6 +1494,9 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
+    "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
@@ -1484,6 +1542,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
+    "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
+    "aws-vpclattice-rule.json",
+    "aws-vpclattice-service.json",
+    "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkserviceassociation.json",
+    "aws-vpclattice-servicenetworkvpcassociation.json",
+    "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-ipset.json",
     "aws-waf-rule.json",
