@@ -62,6 +62,7 @@ types: list[str] = [
     "AWS::AppSync::SourceApiAssociation",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
+    "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -76,6 +77,7 @@ types: list[str] = [
     "AWS::Backup::BackupPlan",
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
     "AWS::Batch::ComputeEnvironment",
@@ -136,7 +138,9 @@ types: list[str] = [
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolResourceServer",
     "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
     "AWS::Cognito::UserPoolUser",
     "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
@@ -147,11 +151,13 @@ types: list[str] = [
     "AWS::Config::DeliveryChannel",
     "AWS::Config::OrganizationConfigRule",
     "AWS::Config::OrganizationConformancePack",
+    "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
     "AWS::DMS::MigrationProject",
@@ -334,6 +340,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -378,6 +385,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -444,6 +452,20 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -464,6 +486,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -489,6 +513,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
     "AWS::ResourceExplorer2::Index",
@@ -539,6 +564,7 @@ types: list[str] = [
     "AWS::SSM::MaintenanceWindowTask",
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
+    "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
     "AWS::SSO::Instance",
@@ -605,6 +631,16 @@ types: list[str] = [
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
     "AWS::VerifiedPermissions::PolicyTemplate",
+    "AWS::VpcLattice::AccessLogSubscription",
+    "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourcePolicy",
+    "AWS::VpcLattice::Rule",
+    "AWS::VpcLattice::Service",
+    "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
+    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
+    "AWS::VpcLattice::TargetGroup",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -635,7 +671,24 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
@@ -649,21 +702,19 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
-    "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -673,11 +724,11 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
     "aws-batch-computeenvironment.json",
@@ -735,7 +786,9 @@ cached: list[str] = [
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
     "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
@@ -746,6 +799,7 @@ cached: list[str] = [
     "aws-config-deliverychannel.json",
     "aws-config-organizationconfigrule.json",
     "aws-config-organizationconformancepack.json",
+    "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
@@ -763,6 +817,7 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
@@ -785,6 +840,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -795,7 +851,7 @@ cached: list[str] = [
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
     "aws-ec2-placementgroup.json",
@@ -828,7 +884,9 @@ cached: list[str] = [
     "aws-ec2-transitgatewayvpcattachment.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -837,7 +895,6 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
-    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -900,6 +957,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -909,6 +967,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -931,21 +990,21 @@ cached: list[str] = [
     "aws-iam-usertogroupaddition.json",
     "aws-identitystore-group.json",
     "aws-identitystore-groupmembership.json",
-    "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
     "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
-    "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-internetmonitor-monitor.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -956,7 +1015,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -989,7 +1047,6 @@ cached: list[str] = [
     "aws-mediapackagev2-channel.json",
     "aws-mediapackagev2-channelgroup.json",
     "aws-mediapackagev2-channelpolicy.json",
-    "aws-mediapackagev2-originendpoint.json",
     "aws-mediapackagev2-originendpointpolicy.json",
     "aws-mediatailor-channel.json",
     "aws-mediatailor-channelpolicy.json",
@@ -1008,9 +1065,22 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1020,11 +1090,10 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-pcaconnectorad-connector.json",
-    "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
-    "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
@@ -1038,6 +1107,7 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
+    "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
@@ -1048,6 +1118,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
@@ -1090,7 +1161,6 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
@@ -1137,6 +1207,7 @@ cached: list[str] = [
     "aws-ssm-maintenancewindowtask.json",
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
+    "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
     "aws-sso-instance.json",
@@ -1158,6 +1229,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
+    "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
+    "aws-vpclattice-rule.json",
+    "aws-vpclattice-service.json",
+    "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkserviceassociation.json",
+    "aws-vpclattice-servicenetworkvpcassociation.json",
+    "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
