@@ -114,6 +114,7 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Backup::Framework",
+    "AWS::Backup::LogicallyAirGappedBackupVault",
     "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
@@ -125,9 +126,14 @@ types: list[str] = [
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::DataSource",
+    "AWS::Bedrock::Flow",
+    "AWS::Bedrock::FlowAlias",
+    "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
     "AWS::Bedrock::KnowledgeBase",
+    "AWS::Bedrock::Prompt",
+    "AWS::Bedrock::PromptVersion",
     "AWS::Budgets::Budget",
     "AWS::Budgets::BudgetsAction",
     "AWS::CDK::Metadata",
@@ -223,6 +229,7 @@ types: list[str] = [
     "AWS::Config::OrganizationConformancePack",
     "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
+    "AWS::Connect::AgentStatus",
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
@@ -243,6 +250,7 @@ types: list[str] = [
     "AWS::Connect::TaskTemplate",
     "AWS::Connect::User",
     "AWS::Connect::UserHierarchyGroup",
+    "AWS::Connect::UserHierarchyStructure",
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ConnectCampaigns::Campaign",
@@ -256,6 +264,7 @@ types: list[str] = [
     "AWS::CustomerProfiles::ObjectType",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DMS::Certificate",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::Endpoint",
     "AWS::DMS::EventSubscription",
@@ -289,6 +298,7 @@ types: list[str] = [
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
     "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
@@ -512,6 +522,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GreengrassV2::ComponentVersion",
     "AWS::GreengrassV2::Deployment",
@@ -601,6 +612,7 @@ types: list[str] = [
     "AWS::Kendra::Faq",
     "AWS::Kendra::Index",
     "AWS::KendraRanking::ExecutionPlan",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalytics::Application",
@@ -753,6 +765,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -771,6 +784,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Panorama::ApplicationInstance",
     "AWS::Panorama::Package",
     "AWS::Panorama::PackageVersion",
@@ -806,6 +821,7 @@ types: list[str] = [
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -837,6 +853,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -924,6 +941,7 @@ types: list[str] = [
     "AWS::SSMContacts::Rotation",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
+    "AWS::SSMQuickSetup::ConfigurationManager",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1067,6 +1085,7 @@ types: list[str] = [
     "AWS::WAFv2::RuleGroup",
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
+    "AWS::Wisdom::AIPrompt",
     "AWS::Wisdom::Assistant",
     "AWS::Wisdom::AssistantAssociation",
     "AWS::Wisdom::KnowledgeBase",
@@ -1142,7 +1161,6 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -1180,7 +1198,6 @@ cached: list[str] = [
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -1191,7 +1208,6 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1202,6 +1218,7 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-framework.json",
+    "aws-backup-logicallyairgappedbackupvault.json",
     "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
@@ -1213,8 +1230,13 @@ cached: list[str] = [
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-datasource.json",
+    "aws-bedrock-flow.json",
+    "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
@@ -1258,6 +1280,7 @@ cached: list[str] = [
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
     "aws-cloudtrail-channel.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -1308,6 +1331,7 @@ cached: list[str] = [
     "aws-config-organizationconformancepack.json",
     "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
+    "aws-connect-agentstatus.json",
     "aws-connect-approvedorigin.json",
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
@@ -1328,6 +1352,7 @@ cached: list[str] = [
     "aws-connect-tasktemplate.json",
     "aws-connect-user.json",
     "aws-connect-userhierarchygroup.json",
+    "aws-connect-userhierarchystructure.json",
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-connectcampaigns-campaign.json",
@@ -1362,6 +1387,7 @@ cached: list[str] = [
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
     "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
@@ -1378,6 +1404,7 @@ cached: list[str] = [
     "aws-directoryservice-microsoftad.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-certificate.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-endpoint.json",
     "aws-dms-eventsubscription.json",
@@ -1414,6 +1441,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1433,7 +1461,6 @@ cached: list[str] = [
     "aws-ec2-networkinsightsaccessscopeanalysis.json",
     "aws-ec2-networkinsightsanalysis.json",
     "aws-ec2-networkinsightspath.json",
-    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-networkperformancemetricsubscription.json",
@@ -1474,6 +1501,7 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
@@ -1575,6 +1603,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -1588,6 +1617,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-greengrassv2-componentversion.json",
     "aws-greengrassv2-deployment.json",
@@ -1674,6 +1704,7 @@ cached: list[str] = [
     "aws-kendra-faq.json",
     "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
@@ -1684,6 +1715,7 @@ cached: list[str] = [
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1695,7 +1727,6 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1718,6 +1749,7 @@ cached: list[str] = [
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
+    "aws-location-apikey.json",
     "aws-location-geofencecollection.json",
     "aws-location-map.json",
     "aws-location-placeindex.json",
@@ -1781,6 +1813,7 @@ cached: list[str] = [
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-serverlesscluster.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
@@ -1821,6 +1854,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1843,6 +1877,8 @@ cached: list[str] = [
     "aws-pcaconnectorad-serviceprincipalname.json",
     "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-personalize-dataset.json",
     "aws-personalize-datasetgroup.json",
     "aws-personalize-schema.json",
@@ -1871,6 +1907,7 @@ cached: list[str] = [
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
@@ -1901,6 +1938,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1961,7 +1999,6 @@ cached: list[str] = [
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
     "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1981,7 +2018,6 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -1990,8 +2026,6 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
-    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -2038,6 +2072,7 @@ cached: list[str] = [
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
     "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
@@ -2069,6 +2104,7 @@ cached: list[str] = [
     "aws-ssmcontacts-rotation.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
+    "aws-ssmquicksetup-configurationmanager.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -2125,6 +2161,7 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
+    "aws-wisdom-aiprompt.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
     "aws-wisdom-knowledgebase.json",
