@@ -119,7 +119,9 @@ types: list[str] = [
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolResourceServer",
     "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
     "AWS::Cognito::UserPoolUser",
     "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
@@ -136,6 +138,7 @@ types: list[str] = [
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
     "AWS::DMS::MigrationProject",
@@ -351,6 +354,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -392,6 +396,20 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -407,6 +425,8 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -430,6 +450,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
     "AWS::ResourceExplorer2::Index",
@@ -457,6 +478,9 @@ types: list[str] = [
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
     "AWS::Route53Resolver::ResolverRule",
     "AWS::Route53Resolver::ResolverRuleAssociation",
+    "AWS::S3::AccessGrant",
+    "AWS::S3::AccessGrantsInstance",
+    "AWS::S3::AccessGrantsLocation",
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
@@ -484,8 +508,12 @@ types: list[str] = [
     "AWS::SSO::Instance",
     "AWS::SSO::InstanceAccessControlAttributeConfiguration",
     "AWS::SSO::PermissionSet",
+    "AWS::SageMaker::Image",
+    "AWS::SageMaker::ImageVersion",
     "AWS::SageMaker::MlflowTrackingServer",
     "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::ModelPackage",
+    "AWS::SageMaker::ModelPackageGroup",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
@@ -556,6 +584,23 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
@@ -569,7 +614,6 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -580,7 +624,6 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
@@ -633,7 +676,9 @@ cached: list[str] = [
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
     "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
@@ -662,6 +707,7 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
@@ -680,6 +726,7 @@ cached: list[str] = [
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-instance.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -690,12 +737,13 @@ cached: list[str] = [
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
+    "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-snapshotblockpublicaccess.json",
@@ -719,7 +767,9 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -727,6 +777,7 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
+    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -754,7 +805,6 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
-    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
@@ -785,6 +835,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -793,6 +844,7 @@ cached: list[str] = [
     "aws-glue-partition.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
+    "aws-glue-trigger.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -801,12 +853,16 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-threatintelset.json",
+    "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
+    "aws-iam-instanceprofile.json",
     "aws-iam-oidcprovider.json",
+    "aws-iam-role.json",
     "aws-iam-rolepolicy.json",
     "aws-iam-samlprovider.json",
     "aws-iam-servercertificate.json",
     "aws-iam-servicelinkedrole.json",
+    "aws-iam-user.json",
     "aws-iam-userpolicy.json",
     "aws-iam-usertogroupaddition.json",
     "aws-identitystore-group.json",
@@ -819,11 +875,13 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -834,6 +892,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -860,9 +919,22 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -872,6 +944,8 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
@@ -895,6 +969,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
@@ -925,18 +1000,22 @@ cached: list[str] = [
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-image.json",
+    "aws-sagemaker-imageversion.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-modelpackage.json",
+    "aws-sagemaker-modelpackagegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
     "aws-securityhub-standard.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
