@@ -50,6 +50,13 @@ types: list[str] = [
     "AWS::AppConfig::Extension",
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
+    "AWS::AppMesh::GatewayRoute",
+    "AWS::AppMesh::Mesh",
+    "AWS::AppMesh::Route",
+    "AWS::AppMesh::VirtualGateway",
+    "AWS::AppMesh::VirtualNode",
+    "AWS::AppMesh::VirtualRouter",
+    "AWS::AppMesh::VirtualService",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
     "AWS::AppSync::DataSource",
@@ -138,7 +145,9 @@ types: list[str] = [
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
     "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolResourceServer",
     "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
     "AWS::Cognito::UserPoolUser",
     "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
@@ -149,11 +158,13 @@ types: list[str] = [
     "AWS::Config::DeliveryChannel",
     "AWS::Config::OrganizationConfigRule",
     "AWS::Config::OrganizationConformancePack",
+    "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
     "AWS::DMS::MigrationProject",
@@ -173,6 +184,11 @@ types: list[str] = [
     "AWS::DataSync::Task",
     "AWS::DirectoryService::MicrosoftAD",
     "AWS::DirectoryService::SimpleAD",
+    "AWS::DocDB::DBCluster",
+    "AWS::DocDB::DBClusterParameterGroup",
+    "AWS::DocDB::DBInstance",
+    "AWS::DocDB::DBSubnetGroup",
+    "AWS::DocDB::EventSubscription",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
     "AWS::EC2::CapacityReservation",
@@ -346,6 +362,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -390,6 +407,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -410,6 +428,13 @@ types: list[str] = [
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
     "AWS::LaunchWizard::Deployment",
+    "AWS::Location::APIKey",
+    "AWS::Location::GeofenceCollection",
+    "AWS::Location::Map",
+    "AWS::Location::PlaceIndex",
+    "AWS::Location::RouteCalculator",
+    "AWS::Location::Tracker",
+    "AWS::Location::TrackerConsumer",
     "AWS::Logs::AccountPolicy",
     "AWS::Logs::Delivery",
     "AWS::Logs::DeliveryDestination",
@@ -430,11 +455,36 @@ types: list[str] = [
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
     "AWS::MWAA::Environment",
+    "AWS::MemoryDB::ACL",
+    "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::ParameterGroup",
+    "AWS::MemoryDB::SubnetGroup",
+    "AWS::MemoryDB::User",
+    "AWS::Neptune::DBCluster",
+    "AWS::Neptune::DBClusterParameterGroup",
+    "AWS::Neptune::DBInstance",
+    "AWS::Neptune::DBParameterGroup",
+    "AWS::Neptune::DBSubnetGroup",
+    "AWS::Neptune::EventSubscription",
     "AWS::NetworkFirewall::Firewall",
     "AWS::NetworkFirewall::FirewallPolicy",
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -455,6 +505,8 @@ types: list[str] = [
     "AWS::PCAConnectorAD::ServicePrincipalName",
     "AWS::PCAConnectorAD::Template",
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::Pipes::Pipe",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
@@ -481,6 +533,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -613,6 +666,16 @@ types: list[str] = [
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
     "AWS::VerifiedPermissions::PolicyTemplate",
+    "AWS::VpcLattice::AccessLogSubscription",
+    "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourcePolicy",
+    "AWS::VpcLattice::Rule",
+    "AWS::VpcLattice::Service",
+    "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
+    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
+    "AWS::VpcLattice::TargetGroup",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -643,7 +706,24 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
@@ -657,7 +737,6 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -666,13 +745,19 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-servicelevelobjective.json",
+    "aws-appmesh-gatewayroute.json",
+    "aws-appmesh-mesh.json",
+    "aws-appmesh-route.json",
+    "aws-appmesh-virtualgateway.json",
+    "aws-appmesh-virtualnode.json",
+    "aws-appmesh-virtualrouter.json",
+    "aws-appmesh-virtualservice.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
     "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -683,7 +768,6 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -749,7 +833,9 @@ cached: list[str] = [
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
     "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
@@ -760,6 +846,7 @@ cached: list[str] = [
     "aws-config-deliverychannel.json",
     "aws-config-organizationconfigrule.json",
     "aws-config-organizationconformancepack.json",
+    "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
@@ -777,10 +864,15 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
     "aws-dms-replicationconfig.json",
+    "aws-docdb-dbcluster.json",
+    "aws-docdb-dbinstance.json",
+    "aws-docdb-dbsubnetgroup.json",
+    "aws-docdb-eventsubscription.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
@@ -799,6 +891,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -809,7 +902,7 @@ cached: list[str] = [
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
     "aws-ec2-placementgroup.json",
@@ -844,7 +937,9 @@ cached: list[str] = [
     "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -853,7 +948,6 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
-    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -927,6 +1021,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -936,6 +1031,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -958,21 +1054,21 @@ cached: list[str] = [
     "aws-iam-usertogroupaddition.json",
     "aws-identitystore-group.json",
     "aws-identitystore-groupmembership.json",
-    "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
     "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
-    "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
     "aws-internetmonitor-monitor.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -988,6 +1084,13 @@ cached: list[str] = [
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
+    "aws-location-apikey.json",
+    "aws-location-geofencecollection.json",
+    "aws-location-map.json",
+    "aws-location-placeindex.json",
+    "aws-location-routecalculator.json",
+    "aws-location-tracker.json",
+    "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
@@ -1002,20 +1105,41 @@ cached: list[str] = [
     "aws-logs-subscriptionfilter.json",
     "aws-m2-application.json",
     "aws-m2-environment.json",
+    "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
+    "aws-memorydb-parametergroup.json",
+    "aws-memorydb-subnetgroup.json",
+    "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
+    "aws-neptune-dbcluster.json",
+    "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1025,11 +1149,10 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-pcaconnectorad-connector.json",
-    "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
-    "aws-pcaconnectorad-template.json",
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
@@ -1055,6 +1178,7 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1094,7 +1218,6 @@ cached: list[str] = [
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
-    "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
@@ -1112,7 +1235,6 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
@@ -1146,7 +1268,6 @@ cached: list[str] = [
     "aws-shield-protection.json",
     "aws-shield-protectiongroup.json",
     "aws-sns-subscription.json",
-    "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
     "aws-sns-topicpolicy.json",
     "aws-sqs-queue.json",
@@ -1181,6 +1302,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
+    "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
+    "aws-vpclattice-rule.json",
+    "aws-vpclattice-service.json",
+    "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkserviceassociation.json",
+    "aws-vpclattice-servicenetworkvpcassociation.json",
+    "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
