@@ -69,6 +69,7 @@ types: list[str] = [
     "AWS::AppSync::SourceApiAssociation",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
+    "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -163,6 +164,7 @@ types: list[str] = [
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
     "AWS::DLM::LifecyclePolicy",
+    "AWS::DMS::DataMigration",
     "AWS::DMS::DataProvider",
     "AWS::DMS::InstanceProfile",
     "AWS::DMS::MigrationProject",
@@ -355,6 +357,7 @@ types: list[str] = [
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
     "AWS::Glue::Trigger",
+    "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -365,6 +368,7 @@ types: list[str] = [
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
+    "AWS::IAM::GroupPolicy",
     "AWS::IAM::InstanceProfile",
     "AWS::IAM::ManagedPolicy",
     "AWS::IAM::OIDCProvider",
@@ -375,6 +379,7 @@ types: list[str] = [
     "AWS::IAM::ServerCertificate",
     "AWS::IAM::ServiceLinkedRole",
     "AWS::IAM::User",
+    "AWS::IAM::UserPolicy",
     "AWS::IAM::UserToGroupAddition",
     "AWS::IdentityStore::Group",
     "AWS::IdentityStore::GroupMembership",
@@ -395,6 +400,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
@@ -476,6 +482,8 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -500,7 +508,10 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
+    "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Workgroup",
     "AWS::Rekognition::Collection",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
     "AWS::ResourceExplorer2::Index",
@@ -547,6 +558,9 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::ReceiptFilter",
+    "AWS::SES::ReceiptRule",
+    "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
     "AWS::SNS::Subscription",
@@ -641,6 +655,16 @@ types: list[str] = [
     "AWS::VerifiedPermissions::Policy",
     "AWS::VerifiedPermissions::PolicyStore",
     "AWS::VerifiedPermissions::PolicyTemplate",
+    "AWS::VpcLattice::AccessLogSubscription",
+    "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::Listener",
+    "AWS::VpcLattice::ResourcePolicy",
+    "AWS::VpcLattice::Rule",
+    "AWS::VpcLattice::Service",
+    "AWS::VpcLattice::ServiceNetwork",
+    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
+    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
+    "AWS::VpcLattice::TargetGroup",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -670,7 +694,23 @@ cached: list[str] = [
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
-    "aws-amazonmq-configuration.json",
+    "aws-apigateway-account.json",
+    "aws-apigateway-apikey.json",
+    "aws-apigateway-authorizer.json",
+    "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-clientcertificate.json",
+    "aws-apigateway-deployment.json",
+    "aws-apigateway-documentationpart.json",
+    "aws-apigateway-documentationversion.json",
+    "aws-apigateway-gatewayresponse.json",
+    "aws-apigateway-method.json",
+    "aws-apigateway-model.json",
+    "aws-apigateway-requestvalidator.json",
+    "aws-apigateway-resource.json",
+    "aws-apigateway-stage.json",
+    "aws-apigateway-usageplan.json",
+    "aws-apigateway-usageplankey.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
@@ -684,12 +724,12 @@ cached: list[str] = [
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -700,11 +740,9 @@ cached: list[str] = [
     "aws-appmesh-virtualservice.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
-    "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
-    "aws-appsync-graphqlapi.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
@@ -714,7 +752,6 @@ cached: list[str] = [
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
@@ -776,7 +813,6 @@ cached: list[str] = [
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
-    "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpoolriskconfigurationattachment.json",
     "aws-cognito-userpooluicustomizationattachment.json",
@@ -811,6 +847,7 @@ cached: list[str] = [
     "aws-detective-memberinvitation.json",
     "aws-detective-organizationadmin.json",
     "aws-dlm-lifecyclepolicy.json",
+    "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
     "aws-dms-migrationproject.json",
@@ -833,6 +870,7 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
+    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -847,12 +885,13 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetablevpcassociation.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
+    "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-snapshotblockpublicaccess.json",
@@ -881,7 +920,9 @@ cached: list[str] = [
     "aws-ec2-verifiedaccesstrustprovider.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
+    "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -890,7 +931,6 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
-    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-replicationconfiguration.json",
@@ -918,7 +958,6 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
-    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
@@ -952,6 +991,7 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
+    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
@@ -961,6 +1001,7 @@ cached: list[str] = [
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
     "aws-glue-trigger.json",
+    "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -970,6 +1011,7 @@ cached: list[str] = [
     "aws-guardduty-member.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
+    "aws-iam-grouppolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-role.json",
     "aws-iam-rolepolicy.json",
@@ -977,6 +1019,7 @@ cached: list[str] = [
     "aws-iam-servercertificate.json",
     "aws-iam-servicelinkedrole.json",
     "aws-iam-user.json",
+    "aws-iam-userpolicy.json",
     "aws-iam-usertogroupaddition.json",
     "aws-identitystore-group.json",
     "aws-identitystore-groupmembership.json",
@@ -988,11 +1031,13 @@ cached: list[str] = [
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
+    "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
@@ -1003,6 +1048,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
@@ -1046,13 +1092,6 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-omics-annotationstore.json",
-    "aws-omics-referencestore.json",
-    "aws-omics-rungroup.json",
-    "aws-omics-sequencestore.json",
-    "aws-omics-variantstore.json",
-    "aws-omics-workflow.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1062,6 +1101,8 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
@@ -1075,6 +1116,7 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
+    "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
@@ -1085,7 +1127,10 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
+    "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-workgroup.json",
     "aws-rekognition-collection.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
@@ -1111,6 +1156,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1126,7 +1172,6 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
-    "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
@@ -1142,13 +1187,13 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
     "aws-securityhub-standard.json",
     "aws-servicecatalog-cloudformationproduct.json",
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
@@ -1175,6 +1220,9 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-receiptfilter.json",
+    "aws-ses-receiptrule.json",
+    "aws-ses-receiptruleset.json",
     "aws-ses-template.json",
     "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
@@ -1215,6 +1263,16 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
+    "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
+    "aws-vpclattice-rule.json",
+    "aws-vpclattice-service.json",
+    "aws-vpclattice-servicenetwork.json",
+    "aws-vpclattice-servicenetworkserviceassociation.json",
+    "aws-vpclattice-servicenetworkvpcassociation.json",
+    "aws-vpclattice-targetgroup.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
