@@ -77,6 +77,7 @@ types: list[str] = [
     "AWS::ApplicationInsights::Application",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
+    "AWS::Athena::PreparedStatement",
     "AWS::Athena::WorkGroup",
     "AWS::AutoScaling::AutoScalingGroup",
     "AWS::AutoScaling::LaunchConfiguration",
@@ -156,6 +157,7 @@ types: list[str] = [
     "AWS::Config::OrganizationConformancePack",
     "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
+    "AWS::Connect::AgentStatus",
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
@@ -173,6 +175,7 @@ types: list[str] = [
     "AWS::Connect::TaskTemplate",
     "AWS::Connect::User",
     "AWS::Connect::UserHierarchyGroup",
+    "AWS::Connect::UserHierarchyStructure",
     "AWS::Connect::View",
     "AWS::Connect::ViewVersion",
     "AWS::ControlTower::EnabledBaseline",
@@ -500,9 +503,13 @@ types: list[str] = [
     "AWS::KinesisFirehose::DeliveryStream",
     "AWS::KinesisVideo::SignalingChannel",
     "AWS::KinesisVideo::Stream",
+    "AWS::LakeFormation::DataCellsFilter",
     "AWS::LakeFormation::DataLakeSettings",
     "AWS::LakeFormation::Permissions",
+    "AWS::LakeFormation::PrincipalPermissions",
     "AWS::LakeFormation::Resource",
+    "AWS::LakeFormation::Tag",
+    "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
     "AWS::Lambda::EventInvokeConfig",
     "AWS::Lambda::EventSourceMapping",
@@ -557,6 +564,12 @@ types: list[str] = [
     "AWS::NetworkManager::TransitGatewayRegistration",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::OpenSearchServerless::AccessPolicy",
+    "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::LifecyclePolicy",
+    "AWS::OpenSearchServerless::SecurityConfig",
+    "AWS::OpenSearchServerless::SecurityPolicy",
+    "AWS::OpenSearchServerless::VpcEndpoint",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -592,6 +605,7 @@ types: list[str] = [
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
+    "AWS::QuickSight::Folder",
     "AWS::QuickSight::RefreshSchedule",
     "AWS::QuickSight::Template",
     "AWS::QuickSight::Theme",
@@ -615,8 +629,13 @@ types: list[str] = [
     "AWS::Redshift::ClusterSecurityGroup",
     "AWS::Redshift::ClusterSecurityGroupIngress",
     "AWS::Redshift::ClusterSubnetGroup",
+    "AWS::Redshift::EndpointAccess",
+    "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
+    "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Workgroup",
     "AWS::Rekognition::Collection",
     "AWS::ResilienceHub::App",
     "AWS::ResilienceHub::ResiliencyPolicy",
@@ -683,6 +702,7 @@ types: list[str] = [
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
+    "AWS::SSO::Instance",
     "AWS::SSO::InstanceAccessControlAttributeConfiguration",
     "AWS::SSO::PermissionSet",
     "AWS::SageMaker::App",
@@ -800,7 +820,6 @@ cached: list[str] = [
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
-    "aws-amazonmq-configuration.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -821,12 +840,10 @@ cached: list[str] = [
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
-    "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-stage.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
-    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -854,8 +871,8 @@ cached: list[str] = [
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
-    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
@@ -884,6 +901,7 @@ cached: list[str] = [
     "aws-cloudformation-stackset.json",
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
@@ -897,14 +915,16 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
+    "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
     "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
-    "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
     "aws-cognito-userpooluicustomizationattachment.json",
     "aws-cognito-userpooluser.json",
@@ -917,6 +937,7 @@ cached: list[str] = [
     "aws-config-organizationconformancepack.json",
     "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
+    "aws-connect-agentstatus.json",
     "aws-connect-approvedorigin.json",
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
@@ -934,6 +955,7 @@ cached: list[str] = [
     "aws-connect-tasktemplate.json",
     "aws-connect-user.json",
     "aws-connect-userhierarchygroup.json",
+    "aws-connect-userhierarchystructure.json",
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-controltower-enabledbaseline.json",
@@ -979,6 +1001,7 @@ cached: list[str] = [
     "aws-ec2-clientvpnendpoint.json",
     "aws-ec2-clientvpnroute.json",
     "aws-ec2-clientvpntargetnetworkassociation.json",
+    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
@@ -1003,12 +1026,13 @@ cached: list[str] = [
     "aws-ec2-localgatewayroutetablevpcassociation.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
-    "aws-ec2-networkinterface.json",
+    "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterfacepermission.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
     "aws-ec2-routetable.json",
+    "aws-ec2-securitygroup.json",
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-snapshotblockpublicaccess.json",
@@ -1047,6 +1071,7 @@ cached: list[str] = [
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
+    "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-repository.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
@@ -1059,7 +1084,6 @@ cached: list[str] = [
     "aws-efs-filesystem.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
-    "aws-eks-cluster.json",
     "aws-eks-identityproviderconfig.json",
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
@@ -1067,6 +1091,8 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -1086,7 +1112,6 @@ cached: list[str] = [
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
-    "aws-fis-experimenttemplate.json",
     "aws-fis-targetaccountconfiguration.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-snapshot.json",
@@ -1096,19 +1121,16 @@ cached: list[str] = [
     "aws-glue-connection.json",
     "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
-    "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
     "aws-glue-dataqualityruleset.json",
     "aws-glue-devendpoint.json",
-    "aws-glue-job.json",
     "aws-glue-mltransform.json",
     "aws-glue-partition.json",
-    "aws-glue-registry.json",
-    "aws-glue-schema.json",
     "aws-glue-schemaversion.json",
     "aws-glue-schemaversionmetadata.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
+    "aws-glue-trigger.json",
     "aws-glue-workflow.json",
     "aws-greengrass-connectordefinition.json",
     "aws-greengrass-connectordefinitionversion.json",
@@ -1196,20 +1218,25 @@ cached: list[str] = [
     "aws-iottwinmaker-scene.json",
     "aws-iottwinmaker-syncjob.json",
     "aws-iottwinmaker-workspace.json",
-    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
+    "aws-kinesisfirehose-deliverystream.json",
     "aws-kinesisvideo-signalingchannel.json",
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
+    "aws-kms-replicakey.json",
+    "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
     "aws-lakeformation-permissions.json",
+    "aws-lakeformation-principalpermissions.json",
     "aws-lakeformation-resource.json",
+    "aws-lakeformation-tag.json",
+    "aws-lakeformation-tagassociation.json",
+    "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-function.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
@@ -1222,8 +1249,6 @@ cached: list[str] = [
     "aws-location-tracker.json",
     "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
-    "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
@@ -1232,7 +1257,6 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-m2-application.json",
     "aws-m2-environment.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
@@ -1255,6 +1279,12 @@ cached: list[str] = [
     "aws-networkmanager-transitgatewayregistration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchserverless-accesspolicy.json",
+    "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
+    "aws-opensearchserverless-securitypolicy.json",
+    "aws-opensearchserverless-vpcendpoint.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1285,23 +1315,26 @@ cached: list[str] = [
     "aws-quicksight-dashboard.json",
     "aws-quicksight-dataset.json",
     "aws-quicksight-datasource.json",
+    "aws-quicksight-folder.json",
     "aws-quicksight-refreshschedule.json",
     "aws-quicksight-template.json",
     "aws-quicksight-theme.json",
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
-    "aws-rds-dbcluster.json",
-    "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
-    "aws-rds-dbparametergroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
-    "aws-rds-dbsubnetgroup.json",
-    "aws-rds-eventsubscription.json",
-    "aws-rds-optiongroup.json",
+    "aws-redshift-cluster.json",
+    "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
+    "aws-redshift-clustersubnetgroup.json",
+    "aws-redshift-endpointaccess.json",
+    "aws-redshift-endpointauthorization.json",
+    "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
+    "aws-redshift-scheduledaction.json",
+    "aws-redshiftserverless-workgroup.json",
     "aws-rekognition-collection.json",
     "aws-resiliencehub-app.json",
     "aws-resiliencehub-resiliencypolicy.json",
@@ -1316,8 +1349,6 @@ cached: list[str] = [
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
-    "aws-route53profiles-profileassociation.json",
-    "aws-route53profiles-profileresourceassociation.json",
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
@@ -1328,9 +1359,6 @@ cached: list[str] = [
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
     "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
-    "aws-s3-accessgrant.json",
-    "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -1343,8 +1371,6 @@ cached: list[str] = [
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
-    "aws-sagemaker-domain.json",
-    "aws-sagemaker-endpoint.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
@@ -1361,8 +1387,6 @@ cached: list[str] = [
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
-    "aws-secretsmanager-secret.json",
-    "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
@@ -1375,6 +1399,7 @@ cached: list[str] = [
     "aws-securityhub-securitycontrol.json",
     "aws-securityhub-standard.json",
     "aws-securitylake-awslogsource.json",
+    "aws-securitylake-datalake.json",
     "aws-securitylake-subscriber.json",
     "aws-securitylake-subscribernotification.json",
     "aws-servicecatalog-cloudformationproduct.json",
@@ -1408,7 +1433,6 @@ cached: list[str] = [
     "aws-signer-signingprofile.json",
     "aws-simspaceweaver-simulation.json",
     "aws-sns-subscription.json",
-    "aws-sns-topic.json",
     "aws-sns-topicpolicy.json",
     "aws-sqs-queue.json",
     "aws-sqs-queuepolicy.json",
@@ -1423,13 +1447,13 @@ cached: list[str] = [
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
+    "aws-sso-instance.json",
     "aws-sso-instanceaccesscontrolattributeconfiguration.json",
     "aws-sso-permissionset.json",
     "aws-stepfunctions-activity.json",
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
-    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-timestream-database.json",
     "aws-timestream-scheduledquery.json",
