@@ -123,16 +123,30 @@ class GetAtt(BaseFn):
                         pointer = getatts.match(region, [resource_name, attribute_name])
 
                         getatt_schema = schema.resolver.resolve_cfn_pointer(pointer)
+                        # there is one exception we need to handle.  The resource type
+                        # has a mix of types the input is integer and the output
+                        # is string.  Since this is the only occurence
+                        # we are putting in an exception to it.
+                        if (
+                            validator.context.resources[resource_name].type
+                            == "AWS::DocDB::DBCluster"
+                            and attribute_name == "Port"
+                        ):
+                            getatt_schema = {"type": "string"}
+
                         if not getatt_schema.get("type") or not s.get("type"):
                             continue
 
                         schema_types = ensure_list(getatt_schema.get("type"))
-
                         types = ensure_list(s.get("type"))
 
-                        if is_types_compatible(
-                            types, schema_types, validator.context.strict_types
-                        ):
+                        # GetAtt type checking is strict.
+                        # It must match in all cases
+                        if any(t in ["boolean", "integer", "boolean"] for t in types):
+                            # this should be switched to validate the value of the
+                            # property if it was available
+                            continue
+                        if is_types_compatible(types, schema_types, True):
                             continue
 
                         reprs = ", ".join(repr(type) for type in types)
